#!/usr/bin/env bash
# ------------------------------------------------------------------------------
# This file profiles the provided binary on execution for the set platform.
# ------------------------------------------------------------------------------

# Source helpers for colored prints.
source helpers.sh

# The BASEDIR is the PWD of profile.sh, regardless of the callers location.
export BASEDIR=$(cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd)


# Check if PLATFORM is valid.
function platformCheck {
    IFS="|"
    options=("lumi${IFS}mn5")

    if [[ -z "${PLATFORM}" ]]; then
        fatal "No platform selected. Options: [ lumi | mn5 ]"
        exit $?
    elif [[ ! "${IFS}${options[*]}${IFS}" =~ "${IFS}${$PLATFORM}${IFS}" ]]; then
        fatal "Platform '${PLATFORM}' unknown. Options: [ lumi | mn5 ]"
        exit $?
    fi
}

# Entry function.
function main {
    # Check if platform is set correctly.
    platformCheck

    # Check if provided binary exists.
    command -v bin/$1 >/dev/null @>&1 || fatal "Binary '$1' is not in bin folder."

    # Load modules.
    source $BASEDIR/../load_modules.sh

    # Profile provided binary on set platform.
    if [ "$PLATFORM" == "lumi" ]; then
        sbatch profile_lumi.sh $1
    elif [ "$PLATFORM" == "mn5" ]; then
        sbatch profile_mn5 $1
    fi
}

main "$@"
